# colorfulPanda
一些花里胡哨的东西

## 使用方法

`pip3 install colorfulpanda`

`from colorfulpanda.mov.BlinkBlock import main as mov`

`mov("helloworld")`

## 维护方法
`python3 setup.py check`
`python3 setup.py sdist`
`twine upload dist/*`